@@ -14,6 +14,11 @@
 #include "gsmessage.h"
 #include "callbacks.h"
 
+static void save_window_size(GtkWidget *window, gint *w, gint *h)
+{
+        gdk_window_get_geometry(window->window, NULL, NULL, w, h, NULL);
+}
+
 void recent_callback(GtkWidget *w, gpointer *data)
 {
         char *error_msg;
@@ -68,6 +73,7 @@ void toggle_even_pages_callback(GtkWidget *widget, gpointer data)
 {
         gint i, n;
         ggv_window *ggv = (ggv_window *) data;
+        gboolean checked;
 
         g_return_if_fail (ggv!=NULL);
         if((!GTK_GS(ggv->gs)->loaded) || (!GTK_GS(ggv->gs)->structured_doc))
@@ -75,8 +81,10 @@ void toggle_even_pages_callback(GtkWidget *widget, gpointer data)
 
         n = gtk_gs_document_numpages (GTK_GS (ggv->gs));
         gtk_clist_freeze(GTK_CLIST(ggv->pagelist));
-        for (i = 0; i < n; i++)
-                gtk_check_list_set_toggled (GTK_CHECK_LIST (ggv->pagelist), i, i % 2);
+        for (i = 1; i < n; i += 2) {
+                checked = gtk_check_list_get_toggled(GTK_CHECK_LIST (ggv->pagelist), i);
+                gtk_check_list_set_toggled (GTK_CHECK_LIST (ggv->pagelist), i, !checked);
+        }
         gtk_clist_thaw(GTK_CLIST(ggv->pagelist));
 }
 
@@ -84,6 +92,7 @@ void toggle_odd_pages_callback(GtkWidget *widget, gpointer data)
 {
         gint i, n;
         ggv_window *ggv = (ggv_window *) data;
+        gboolean checked;
 
         g_return_if_fail (ggv!=NULL);
         if((!GTK_GS(ggv->gs)->loaded) || (!GTK_GS(ggv->gs)->structured_doc))
@@ -91,8 +100,10 @@ void toggle_odd_pages_callback(GtkWidget *widget, gpointer data)
 
         n = gtk_gs_document_numpages (GTK_GS (ggv->gs));
         gtk_clist_freeze(GTK_CLIST(ggv->pagelist));
-        for (i = 0; i < n; i++)
-                gtk_check_list_set_toggled (GTK_CHECK_LIST (ggv->pagelist), i, !(i % 2));
+        for (i = 0; i < n; i += 2) {
+                checked = gtk_check_list_get_toggled(GTK_CHECK_LIST (ggv->pagelist), i);
+                gtk_check_list_set_toggled (GTK_CHECK_LIST (ggv->pagelist), i, !checked);
+        }
         gtk_clist_thaw(GTK_CLIST(ggv->pagelist));
 }
 
@@ -100,6 +111,7 @@ void toggle_all_pages_callback(GtkWidget *widget, gpointer data)
 {
         gint i, n;
         ggv_window *ggv = (ggv_window *) data;
+        gboolean checked;
 
         g_return_if_fail (ggv!=NULL);
         if((!GTK_GS(ggv->gs)->loaded) || (!GTK_GS(ggv->gs)->structured_doc))
@@ -107,8 +119,10 @@ void toggle_all_pages_callback(GtkWidget *widget, gpointer data)
 
         n = gtk_gs_document_numpages (GTK_GS (ggv->gs));
         gtk_clist_freeze(GTK_CLIST(ggv->pagelist));
-        for (i = 0; i < n; i++)
-                gtk_check_list_set_toggled (GTK_CHECK_LIST (ggv->pagelist), i, TRUE);
+        for (i = 0; i < n; i++) {
+                checked = gtk_check_list_get_toggled(GTK_CHECK_LIST (ggv->pagelist), i);
+                gtk_check_list_set_toggled (GTK_CHECK_LIST (ggv->pagelist), i, !checked);
+        }
         gtk_clist_thaw(GTK_CLIST(ggv->pagelist));
 }
 
@@ -177,20 +191,13 @@ void new_callback(GtkWidget *widget, gpointer data)
 }
 
 void button_press_callback(GtkWidget *widget, GdkEventButton *event,
-				  gpointer data)
+                           gpointer data)
 {
         ggv_window *ggv = (ggv_window *)data;
         gint button = event->button;
-        gint x = 0;
-        gint y = 0;
 
-        if (event->window == GTK_GS (ggv->gs)->pstarget) {
-                gdk_window_get_position (event->window, &x, &y);
-        }
-        x += event->x;
-        y += event->y;
         switch(button) {
-        case 1:
+        case 1: {
                 if(!ggv->pan) {
                         gint wx = 0, wy = 0;
 
@@ -209,18 +216,24 @@ void button_press_callback(GtkWidget *widget, GdkEventButton *event,
                         ggv->prev_y = wy;
                 }
                 break;
-        case 2:
-                /* uncomment this to mark a section to crop.
-                 * it has been removed until it clears correctly */        
-#if 0     
-                clear_crop (ggv->cd, ggv->gs->window);
-                crop_button_clicked (ggv->cd, x, y);
-                draw_crop (ggv->cd, ggv->gs->window);
-#endif
-              
+        }
+        case 2: {
+                gfloat cx, cy;
+                gint x = 0, y = 0;
+                
+                if (event->window != GTK_GS (ggv->gs)->pstarget)
+                        break;
+
+                x += event->x;
+                y += event->y;
+
+                cx = (gfloat)x/(gfloat)GTK_GS(ggv->gs)->width;
+                cy = (gfloat)y/(gfloat)GTK_GS(ggv->gs)->height;
+                zoom_to(ggv, ggv->zoom_magstep + 1);
+                gtk_gs_set_center(GTK_GS(ggv->gs), cx, cy);
                 break;
-                /* Support for wheel mice */
-        case 3:
+        }
+        case 3: {
                 gnome_popup_menu_do_popup(ggv->popup_menu, NULL, NULL, event, ggv);
                 if(ggv->menus_vis_pu)
                         gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ggv->menus_vis_pu),
@@ -232,8 +245,9 @@ void button_press_callback(GtkWidget *widget, GdkEventButton *event,
                         gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ggv->panel_vis_pu),
                                                        ggv->show_panel);
                 break;
-                /* Support for wheel mice */
-	case 4:
+        }
+        /* Support for wheel mice */
+	case 4: {
 		if(event->state & GDK_CONTROL_MASK)
 			gtk_gs_scroll(GTK_GS(ggv->gs), -64, 0);
 		else if(event->state & GDK_SHIFT_MASK)
@@ -241,7 +255,8 @@ void button_press_callback(GtkWidget *widget, GdkEventButton *event,
 		else
 			gtk_gs_scroll(GTK_GS(ggv->gs), 0, -64);
 		break;
-	case 5:
+        }
+	case 5: {
 		if(event->state & GDK_CONTROL_MASK)
 			gtk_gs_scroll(GTK_GS(ggv->gs), 64, 0);
 		else if(event->state & GDK_SHIFT_MASK)
@@ -249,6 +264,7 @@ void button_press_callback(GtkWidget *widget, GdkEventButton *event,
 		else
 			gtk_gs_scroll(GTK_GS(ggv->gs), 0, 64);
 		break;
+        }
         default:
                 break;
         }
@@ -289,11 +305,7 @@ gint exit_callback(GtkWidget *widget, gpointer data)
         GList *node;
 
         /* do we want to save anything before we exit??? */        
-
-
         while (window_list) {
-
-
                 node = window_list;
                 window_list = window_list->next;
                 if(window_list)
@@ -327,6 +339,7 @@ void file_open_cancel_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *)data;
 
+        save_window_size(ggv->file_sel, &file_sel_width, &file_sel_height);
         gtk_widget_destroy(ggv->file_sel);
         ggv->file_sel = NULL;
 }
@@ -345,6 +358,7 @@ void file_open_ok_callback(GtkWidget *widget, gpointer data)
         char *error_msg;
         struct stat stat_rec;
 
+        save_window_size(ggv->file_sel, &file_sel_width, &file_sel_height);
 	file = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(ggv->file_sel)));
 
         /* We have to verify that this file exists */
@@ -591,31 +605,42 @@ void key_pressed_event_callback(GtkWidget *widget, GdkEventKey *event,
                 case GTK_GS_ORIENTATION_PORTRAIT:
                         if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane), 
                                                  GTK_SCROLLPANE_SCROLL_DOWN, TRUE)) {
-                                /* Since we are doing wrapping, go to top of the page */
-                                gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
-                                                         GTK_SCROLLPANE_GOTOEDGE_LOWER, 
-                                                         GTK_SCROLLPANE_GOTOEDGE_LOWER);
-                                /* g_print("Scroll Return false\n"); */
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page + 1);
+                                if(ggv->pane_auto_jump)
+                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
+                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER, 
+                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER);
                         }
                         break;
                 case GTK_GS_ORIENTATION_LANDSCAPE:
                         if (!gtk_scrollpane_step (GTK_SCROLLPANE (ggv->scrollpane),
-                                                       GTK_SCROLLPANE_SCROLL_LEFT,TRUE)) {
-				goto_page( ggv, GTK_GS(ggv->gs)->current_page + 1);
-                        }
+                                                  GTK_SCROLLPANE_SCROLL_LEFT,TRUE)) {
+  				goto_page( ggv, GTK_GS(ggv->gs)->current_page + 1);
+                                if(ggv->pane_auto_jump)
+                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
+                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER, 
+                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER);
+                         }
                         break;
                 case GTK_GS_ORIENTATION_SEASCAPE:
                         if (!gtk_scrollpane_step (GTK_SCROLLPANE (ggv->scrollpane),
                                                   GTK_SCROLLPANE_SCROLL_RIGHT,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page + 1);
-                        }
+                                if(ggv->pane_auto_jump)
+                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
+                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER, 
+                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER);
+                         }
                         break;
                 case GTK_GS_ORIENTATION_UPSIDEDOWN:
                         if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),
-                                                     GTK_SCROLLPANE_SCROLL_UP,TRUE)) {
+                                                 GTK_SCROLLPANE_SCROLL_UP,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page + 1);
-                        }
+                                if(ggv->pane_auto_jump)
+                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
+                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER, 
+                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER);
+                         }
                         break;
                 }
                 break;
@@ -626,22 +651,41 @@ void key_pressed_event_callback(GtkWidget *widget, GdkEventKey *event,
                         if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),
                                                  GTK_SCROLLPANE_SCROLL_UP,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page - 1);
-                        }
+                                if(ggv->pane_auto_jump)
+                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
+                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER, 
+                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER);
+                         }
                         break;
                 case GTK_GS_ORIENTATION_LANDSCAPE:
-                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),GTK_SCROLLPANE_SCROLL_RIGHT,TRUE)) {
+                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),
+                                                 GTK_SCROLLPANE_SCROLL_RIGHT,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page - 1);
-                        }
+                                if(ggv->pane_auto_jump)
+                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
+                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER, 
+                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER);
+                         }
                         break;
                 case GTK_GS_ORIENTATION_SEASCAPE:
-                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),GTK_SCROLLPANE_SCROLL_LEFT,TRUE)) {
+                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),
+                                                 GTK_SCROLLPANE_SCROLL_LEFT,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page - 1);
-                        }
+                                if(ggv->pane_auto_jump)
+                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
+                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER, 
+                                                                 GTK_SCROLLPANE_GOTOEDGE_UPPER);
+                         }
                         break;
                 case GTK_GS_ORIENTATION_UPSIDEDOWN:
-                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),GTK_SCROLLPANE_SCROLL_DOWN,TRUE)) {
+                        if (!gtk_scrollpane_step(GTK_SCROLLPANE (ggv->scrollpane),
+                                                 GTK_SCROLLPANE_SCROLL_DOWN,TRUE)) {
 				goto_page( ggv, GTK_GS(ggv->gs)->current_page - 1);
-                        }
+                                if(ggv->pane_auto_jump)
+                                        gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
+                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER, 
+                                                                 GTK_SCROLLPANE_GOTOEDGE_LOWER);
+                         }
                         break;
                 }
                 break;
@@ -699,12 +743,15 @@ void previous_page_callback(GtkWidget *widget, gpointer data)
 void open_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *)data;
-        gchar *dirname;
+        gchar *dirname = NULL;
 
         if(ggv->file_sel)
                 return;
 
 	ggv->file_sel = gtk_file_selection_new(_("GGv: Open File"));
+        gtk_window_set_default_size(GTK_WINDOW(ggv->file_sel), file_sel_width,
+                                               file_sel_height);
+        gtk_window_set_position(GTK_WINDOW(ggv->file_sel), GTK_WIN_POS_MOUSE);
 	gtk_signal_connect(GTK_OBJECT(ggv->file_sel), "delete_event",
 			   GTK_SIGNAL_FUNC(file_open_delete_callback), data);
 	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(ggv->file_sel)->cancel_button),
@@ -717,13 +764,14 @@ void open_callback(GtkWidget *widget, gpointer data)
         gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(ggv->file_sel));
 
         /* Switch to the directory where the current file came from */
-
         if ((GTK_GS (ggv->gs)->gs_filename != NULL) &&
-	    ((dirname = g_dirname(GTK_GS (ggv->gs)->gs_filename)) != NULL)) {
+	    ((dirname = g_dirname(GTK_GS (ggv->gs)->gs_filename)) != NULL) &&
+            (strcmp(dirname, ".") != 0)) {
                 gtk_file_selection_complete(GTK_FILE_SELECTION(ggv->file_sel),
                                                     dirname);
-		g_free (dirname);
 	}
+        if(dirname)
+		g_free (dirname);
         gtk_widget_show(ggv->file_sel);
 }
 
@@ -794,8 +842,8 @@ void print_marked_pages_callback(GtkWidget *widget, gpointer data)
                 print_command = g_strdup_printf(gs_print_cmd, tmp_name);
                 if(print_command) {
                         gnome_execute_shell(NULL, print_command);
-                        // FIXME: file tmp_name should be unlinked after
-                        // printing...
+                        /* FIXME: file tmp_name should be unlinked after
+                           printing... */
                         g_free(print_command);
                 }
 
@@ -826,6 +874,7 @@ void file_save_cancel_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *)data;
 
+        save_window_size(ggv->save_file_sel, &file_sel_width, &file_sel_height);
         gtk_widget_destroy(ggv->save_file_sel);
         ggv->save_file_sel = NULL;
 }
@@ -844,6 +893,7 @@ void file_save_ok_callback(GtkWidget *widget, gpointer data)
         ggv_window *ggv = (ggv_window *)data;
         gchar *file;
 
+        save_window_size(ggv->save_file_sel, &file_sel_width, &file_sel_height);
 	file = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(ggv->save_file_sel)));
 
         if(stat(file,&stat_rec) == 0) {
@@ -895,10 +945,11 @@ void save_callback(GtkWidget *widget, gpointer data) {
                         error_message(ggv, error_msg);
                         return;
                 }
-        
 
-                
                 ggv->save_file_sel = gtk_file_selection_new(_("GGv: Save marked pages"));
+                gtk_window_set_default_size(GTK_WINDOW(ggv->save_file_sel), file_sel_width,
+                                            file_sel_height);
+                gtk_window_set_position(GTK_WINDOW(ggv->save_file_sel), GTK_WIN_POS_MOUSE);
                 gtk_signal_connect(GTK_OBJECT(ggv->save_file_sel), "delete_event",
                                    GTK_SIGNAL_FUNC(file_save_delete_callback), data);
                 gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(ggv->save_file_sel)->cancel_button),
