@@ -631,6 +631,17 @@ gtk_gs_scroll(GtkGS *gs, gint x_delta, gint y_delta)
                 gtk_adjustment_set_value(gs->vadj, vval);
 }
 
+void
+gtk_gs_set_center(GtkGS *gs, gfloat hval, gfloat vval)
+{
+        if(hval <= gs->hadj->upper - gs->hadj->page_size/2 &&
+           hval >= gs->hadj->lower + gs->hadj->page_size/2)
+                gtk_adjustment_set_value(gs->hadj, hval);
+        if(vval <= gs->vadj->upper - gs->vadj->page_size/2 &&
+           vval >= gs->vadj->lower + gs->vadj->page_size/2)
+                gtk_adjustment_set_value(gs->vadj, vval);
+}        
+
 static void
 send_ps(GtkGS *gs, long begin, unsigned int len, gboolean close)
 {
@@ -1474,24 +1485,12 @@ gtk_gs_goto_page (GtkGS *gs, gint page)
         if (page < 0)
                 page = 0;
         
-        /* 
-         * For some reason, ghost script is unable to accept new input in
-         * the next section.  So, we stop the interpreter and restart it.
-         * I will look for this error later on!
-
-         * Update: This hack is history. This comment should be
-         removed as the fix is well tested.
-
-         */
-        /*        stop_interpreter (gs); */
-        /* End truly bad hack */
-
         if (gs->structured_doc && gs->doc) {
                 if (page >= gs->doc->numpages)
                         page = gs->doc->numpages - 1;
                 
                 if (page == gs->current_page && !gs->changed)
-                        return TRUE;
+                        return FALSE;
                 
                 gs->changed = FALSE;
                 gs->current_page = page;
