@@ -2,7 +2,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 
 /* Scrollpane widget for GTK/GNOME
- * Copyright (C) 1998 Redhat Software Inc.
+ * Copyright (C) 1998 - 2001 Redhat Software Inc.
  * Author: Jonathan Blandford <jrb@redhat.com>
  */
 
@@ -10,9 +10,10 @@
 #include <gtk/gtksignal.h>
 #include "gtkscrollpane.h"
 
-#define SCROLLPANE_CLASS(w)  GTK_SCROLLPANE_CLASS (GTK_OBJECT (w)->klass)
+#define SCROLLPANE_CLASS(w) GTK_SCROLLPANE_CLASS (GTK_OBJECT (w)->klass)
 #define SCROLLPANE_DEFAULT_SIZE 80;
 #define EPSILON 0.00005
+
 enum
   {
     MIDDLE_CLICKED,
@@ -50,8 +51,7 @@ static gint         gtk_scrollpane_focus_in(GtkWidget * widget, GdkEventFocus *
 static gint         gtk_scrollpane_focus_out(GtkWidget * widget, GdkEventFocus * event);
 
 static GtkWidget   *parent_class = NULL;
-static guint        scrollpane_signals[LAST_SIGNAL] =
-{0};
+static guint        scrollpane_signals[LAST_SIGNAL] = {0};
 
 /* Static, private functions */
 guint
@@ -130,6 +130,7 @@ gtk_scrollpane_class_init(GtkScrollpaneClass * klass)
 
   widget_class->realize = gtk_scrollpane_realize;
   widget_class->expose_event = gtk_scrollpane_expose;
+  widget_class->draw = gtk_scrollpane_draw;
   widget_class->size_request = gtk_scrollpane_size_request;
   widget_class->size_allocate = gtk_scrollpane_size_allocate;
   widget_class->button_press_event = gtk_scrollpane_button_press;
@@ -493,12 +494,10 @@ gtk_scrollpane_style_set(GtkWidget * widget, GtkStyle * previous_style)
 }
 
 /* Events... */
-static              gint
+static gint
 gtk_scrollpane_expose(GtkWidget * widget, GdkEventExpose * event)
 {
   GtkScrollpane      *sp;
-  gint                xt;
-  gint                yt;
 
   g_return_val_if_fail(widget != NULL, FALSE);
   g_return_val_if_fail(GTK_IS_SCROLLPANE(widget), FALSE);
@@ -506,9 +505,6 @@ gtk_scrollpane_expose(GtkWidget * widget, GdkEventExpose * event)
 
   sp = GTK_SCROLLPANE(widget);
 
-  yt = widget->style->klass->ythickness;
-  xt = widget->style->klass->xthickness;
-
   /* where did the expose occur??? */
   /* if it did in the trough, then... */
   if (event->window == sp->trough) {
@@ -523,7 +519,7 @@ gtk_scrollpane_expose(GtkWidget * widget, GdkEventExpose * event)
   return FALSE;
 }
 
-static              gint
+static gint
 gtk_scrollpane_button_press(GtkWidget * widget,
 			    GdkEventButton * event)
 {
@@ -552,7 +548,7 @@ gtk_scrollpane_button_press(GtkWidget * widget,
   return TRUE;
 }
 
-static              gint
+static gint
 gtk_scrollpane_button_release(GtkWidget * widget,
 			      GdkEventButton * event)
 {
@@ -575,7 +571,7 @@ gtk_scrollpane_button_release(GtkWidget * widget,
   return TRUE;
 }
 
-GtkWidget          *
+GtkWidget *
 gtk_scrollpane_new(GtkAdjustment * Xadjustment,
 		   GtkAdjustment * Yadjustment,
 		   gint aspect_ratio)
@@ -601,6 +597,7 @@ gtk_scrollpane_new(GtkAdjustment * Xadjustment,
 
   return GTK_WIDGET(retval);
 }
+
 gboolean 
 gtk_scrollpane_goto_edge(GtkScrollpane * sp, gint vertical, gint horizontal)
 {
@@ -734,14 +731,11 @@ gtk_scrollpane_step(GtkScrollpane * sp, gint direction, gboolean dowrap)
     return TRUE;
   }
   
-  /* Now we know we can move in the direction sought */
-  
-  
+  /* Now we know we can move in the direction sought */  
   ADVANCE_STEP(MainAdj,DirectionFlag);
   
   if (CHECK_THERE_IS_NO_SPACE_FOR_STEP(MainAdj,DirectionFlag)) {
     /* We move it too far, lets move it to the edge */
-
     MOVE_TO_EDGE(MainAdj,DirectionFlag);
   }
   gtk_adjustment_value_changed(MainAdj);
@@ -762,6 +756,7 @@ gtk_scrollpane_adjustment_changed(GtkAdjustment * adjustment, gpointer data)
     return;
   gtk_scrollpane_update_slider_size(GTK_SCROLLPANE(data));
 }
+
 static void
 gtk_scrollpane_value_adjustment_changed(GtkAdjustment * adjustment, gpointer data)
 {
@@ -774,13 +769,13 @@ gtk_scrollpane_value_adjustment_changed(GtkAdjustment * adjustment, gpointer dat
   gtk_scrollpane_update_slider_size(GTK_SCROLLPANE(data));
 }
 
-static              gint
+static gint
 gtk_scrollpane_key_press(GtkWidget * widget, GdkEventKey * event)
 {
   return TRUE;
 }
 
-static              gint
+static gint
 gtk_scrollpane_enter_notify(GtkWidget * widget, GdkEventCrossing * event)
 {
   GtkScrollpane *pane = GTK_SCROLLPANE(widget);
@@ -794,7 +789,7 @@ gtk_scrollpane_enter_notify(GtkWidget * widget, GdkEventCrossing * event)
   return FALSE;
 }
 
-static              gint
+static gint
 gtk_scrollpane_leave_notify(GtkWidget * widget, GdkEventCrossing * event)
 {
   GtkScrollpane *pane = GTK_SCROLLPANE(widget);
@@ -806,7 +801,7 @@ gtk_scrollpane_leave_notify(GtkWidget * widget, GdkEventCrossing * event)
   return FALSE;
 }
 
-static              gint
+static gint
 gtk_scrollpane_motion_notify(GtkWidget * widget, GdkEventMotion * event)
 {
   GtkScrollpane      *sp;
@@ -842,7 +837,6 @@ gtk_scrollpane_motion_notify(GtkWidget * widget, GdkEventMotion * event)
 	}
       else if (event->window == sp->slider)
 	{
-
 	  if (x + width + event->x - sp->x_offset > sp->trough_width + widget->style->klass->xthickness)
 	    x = sp->trough_width + widget->style->klass->xthickness - width;
 	  else if (x + event->x - sp->x_offset > widget->style->klass->xthickness)
@@ -860,6 +854,8 @@ gtk_scrollpane_motion_notify(GtkWidget * widget, GdkEventMotion * event)
 	  gdk_window_move(sp->slider, x, y);
 	}
 
+      x -= widget->style->klass->xthickness;
+      y -= widget->style->klass->ythickness;
 
       /* first we check the x adjustment... */
       value = ((sp->Xadjustment->upper - sp->Xadjustment->lower) *
@@ -871,10 +867,6 @@ gtk_scrollpane_motion_notify(GtkWidget * widget, GdkEventMotion * event)
 	/*ugh -- yucky hack. to guarentee that value + page_size/2 < upper */
 	gtk_adjustment_set_value(sp->Xadjustment, sp->Xadjustment->upper - sp->Xadjustment->page_size / 2 - 0.0001);
 
-      /* g_print("SCRADJ: X: xu=%f xl=%f x=%d w=%d v=%f ps=%f value=%f\n",
-       *	sp->Xadjustment->upper, sp->Xadjustment->lower, x, width, value, sp->Xadjustment->page_size, value);
-       */
-
       /* then the y adjustment... */
       value = ((sp->Yadjustment->upper - sp->Yadjustment->lower) *
 	       (y + ((gfloat) height) / 2) /
@@ -885,16 +877,17 @@ gtk_scrollpane_motion_notify(GtkWidget * widget, GdkEventMotion * event)
 	/*ugh -- yucky hack. to guarentee that value + page_size/2 < upper */
 	gtk_adjustment_set_value(sp->Yadjustment, sp->Yadjustment->upper - sp->Yadjustment->page_size / 2 - 0.0001);
     }
+
   return TRUE;
 }
 
-static              gint
+static gint
 gtk_scrollpane_focus_in(GtkWidget * widget, GdkEventFocus * event)
 {
   return TRUE;
 }
 
-static              gint
+static gint
 gtk_scrollpane_focus_out(GtkWidget * widget, GdkEventFocus * event)
 {
   return TRUE;
