@@ -603,7 +603,12 @@ void set_page_sensitivities(ggv_window *ggv, int page)
 
 void goto_page(ggv_window *ggv, int page)
 {
-        gtk_gs_goto_page( GTK_GS(ggv->gs), page);
+        if(gtk_gs_goto_page( GTK_GS(ggv->gs), page) &&
+           gs_auto_jump) {
+                gtk_scrollpane_goto_edge(GTK_SCROLLPANE (ggv->scrollpane),
+                                         GTK_SCROLLPANE_GOTOEDGE_LOWER, 
+                                         GTK_SCROLLPANE_GOTOEDGE_LOWER);
+         }
 
         if(GTK_GS(ggv->gs)->structured_doc) {
                 page = GTK_GS(ggv->gs)->current_page; /* Make sure */
@@ -637,16 +642,16 @@ void create_popup_menus(ggv_window *ggv)
            of the corresponding items in the popupMenu[] array! */
         GnomeUIInfo popupMenu[] = {
 #define PU_NEXT_PAGE_INDEX 0
-                {GNOME_APP_UI_ITEM, N_("Next Page"), NULL, next_page_callback, NULL, NULL,
+                {GNOME_APP_UI_ITEM, N_("_Next Page"), NULL, next_page_callback, NULL, NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_FORWARD, 0, 0, NULL},
 #define PU_PREV_PAGE_INDEX 1
-                {GNOME_APP_UI_ITEM, N_("Previous Page"), NULL, previous_page_callback, NULL, NULL,
+                {GNOME_APP_UI_ITEM, N_("_Previous Page"), NULL, previous_page_callback, NULL, NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BACK, 0, 0, NULL},
                 {GNOME_APP_UI_ITEM, N_("Zoom In"), NULL, zoomin_callback, NULL, NULL,
-                 GNOME_APP_PIXMAP_NONE, GNOME_STOCK_MENU_FORWARD, 0, 0, NULL},
+                 GNOME_APP_PIXMAP_NONE, GNOME_STOCK_MENU_FORWARD, '+', GDK_CONTROL_MASK, NULL},
                 {GNOME_APP_UI_ITEM, N_("Zoom Out"), NULL, zoomout_callback, NULL, NULL,
-                 GNOME_APP_PIXMAP_NONE, GNOME_STOCK_MENU_BACK, 0, 0, NULL},
-                {GNOME_APP_UI_ITEM, N_("Recenter Page"), NULL, recenter_page_callback, NULL, NULL,
+                 GNOME_APP_PIXMAP_NONE, GNOME_STOCK_MENU_BACK, '-', GDK_CONTROL_MASK, NULL},
+                {GNOME_APP_UI_ITEM, N_("_Recenter Page"), NULL, recenter_page_callback, NULL, NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
                 {GNOME_APP_UI_SEPARATOR},
 #define PU_PAGE_MENUS_INDEX 6
@@ -665,11 +670,11 @@ void create_popup_menus(ggv_window *ggv)
                 {GNOME_APP_UI_TOGGLEITEM, N_("Show _Menus"), NULL, show_menubar_callback, NULL, NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 'm', GDK_CONTROL_MASK, NULL},
 #define PU_SHOW_PANEL_INDEX 13
-                {GNOME_APP_UI_TOGGLEITEM, N_("Show Side Panel"), NULL, hide_panel_callback, NULL, NULL,
-                 GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+                {GNOME_APP_UI_TOGGLEITEM, N_("Show _Side Panel"), NULL, hide_panel_callback, NULL, NULL,
+                 GNOME_APP_PIXMAP_NONE, NULL, 's', GDK_CONTROL_MASK, NULL},
 #define PU_SHOW_TOOLBAR_INDEX 14
-                {GNOME_APP_UI_TOGGLEITEM, N_("Show Toolbar"), NULL, show_toolbar_callback, NULL, NULL,
-                 GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},		 
+                {GNOME_APP_UI_TOGGLEITEM, N_("Show _Toolbar"), NULL, show_toolbar_callback, NULL, NULL,
+                 GNOME_APP_PIXMAP_NONE, NULL, 't', GDK_CONTROL_MASK, NULL},		 
                 {GNOME_APP_UI_ENDOFINFO}
         };
                 
@@ -698,22 +703,25 @@ void create_menus(ggv_window *retval, window_with_data *temp)
 {
         int i;
 
+/* Use temporaries for non-compile-time constants. */
+#define TMPVAL(i,orig)          ((void *) (0xC0DE0000 | (i)))
+#define SETVAL(i,val,orig)	g_assert((val) == TMPVAL(i,orig)); val = orig
        
         GnomeUIInfo orientationMenu2[] = {
-                GNOMEUIINFO_ITEM_DATA(N_("_Portrait"), N_("Portrait orientation"), orientation_callback, &temp[0], NULL),
-                GNOMEUIINFO_ITEM_DATA(N_("_Landscape"), N_("Landscape orientation"), orientation_callback, &temp[1], NULL),
-                GNOMEUIINFO_ITEM_DATA(N_("_Upside Down"), N_("Upside down orientation"), orientation_callback, &temp[2], NULL),
-                GNOMEUIINFO_ITEM_DATA(N_("_Seascape"), N_("Seascape orientation"), orientation_callback, &temp[3], NULL),
+                GNOMEUIINFO_ITEM_DATA(N_("_Portrait"), N_("Portrait orientation"), orientation_callback,  TMPVAL(0,&temp[0]), NULL),
+                GNOMEUIINFO_ITEM_DATA(N_("_Landscape"), N_("Landscape orientation"), orientation_callback, TMPVAL(1,&temp[1]), NULL),
+                GNOMEUIINFO_ITEM_DATA(N_("_Upside Down"), N_("Upside down orientation"), orientation_callback, TMPVAL(2,&temp[2]), NULL),
+                GNOMEUIINFO_ITEM_DATA(N_("_Seascape"), N_("Seascape orientation"), orientation_callback, TMPVAL(3,&temp[3]), NULL),
                 GNOMEUIINFO_END
         };
         
         GnomeUIInfo orientationMenu[] = {
                 {GNOME_APP_UI_TOGGLEITEM, N_("_Override Document Orientation"), N_("Override the orientation of the document."), 
                  override_orientation_callback, 
-                 retval, NULL,
+                 TMPVAL(4,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
                 {GNOME_APP_UI_SEPARATOR},
-                GNOMEUIINFO_RADIOLIST(orientationMenu2),
+                GNOMEUIINFO_RADIOLIST(TMPVAL(5,orientationMenu2)),
                 GNOMEUIINFO_END
         };
         
@@ -735,160 +743,250 @@ void create_menus(ggv_window *retval, window_with_data *temp)
 #else
         /* Lets try a percentage. The ratio does not seem to be not clear to everybuddy */ 
         GnomeUIInfo zoomMenu2[] = {
-                GNOMEUIINFO_RADIOITEM_DATA(ZoomMagnLabels[0], NULL, zoom_callback, &temp[4] , NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(ZoomMagnLabels[1], NULL, zoom_callback, &temp[5], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(ZoomMagnLabels[2], NULL, zoom_callback, &temp[6], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(ZoomMagnLabels[3], NULL, zoom_callback, &temp[7], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(ZoomMagnLabels[4], NULL, zoom_callback, &temp[8], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(ZoomMagnLabels[5], NULL, zoom_callback, &temp[9], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(ZoomMagnLabels[6], NULL, zoom_callback, &temp[10], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(ZoomMagnLabels[7], NULL, zoom_callback, &temp[11], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(ZoomMagnLabels[8], NULL, NULL, &temp[14], NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(6,ZoomMagnLabels[0]), NULL, zoom_callback, TMPVAL(7,&temp[4]) , NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(8,ZoomMagnLabels[1]), NULL, zoom_callback, TMPVAL(9,&temp[5]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(10,ZoomMagnLabels[2]), NULL, zoom_callback, TMPVAL(11,&temp[6]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(12,ZoomMagnLabels[3]), NULL, zoom_callback, TMPVAL(13,&temp[7]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(14,ZoomMagnLabels[4]), NULL, zoom_callback, TMPVAL(15,&temp[8]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(16,ZoomMagnLabels[5]), NULL, zoom_callback, TMPVAL(17,&temp[9]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(18,ZoomMagnLabels[6]), NULL, zoom_callback, TMPVAL(19,&temp[10]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(20,ZoomMagnLabels[7]), NULL, zoom_callback, TMPVAL(21,&temp[11]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(22,ZoomMagnLabels[8]), NULL, NULL, TMPVAL(23,&temp[14]), NULL),
                 GNOMEUIINFO_END,
         };
 #endif
 
 
         GnomeUIInfo paperMenu2[] = {
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[0].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[1].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+1], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[2].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+2], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[3].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+3], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[4].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+4], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[5].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+5], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[6].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+6], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[7].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+7], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[8].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+8], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[9].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+9], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[10].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+10], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[11].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+11], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[12].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+12], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[13].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+13], NULL),
-                GNOMEUIINFO_RADIOITEM_DATA(papersizes[14].name, NULL, paper_callback,  
-                                           &temp[MENU_DATA_PAPER_OFFSET+14], NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(24,papersizes[0].name), NULL, paper_callback,  
+                                           TMPVAL(25,&temp[MENU_DATA_PAPER_OFFSET]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(26,papersizes[1].name), NULL, paper_callback,  
+                                           TMPVAL(27,&temp[MENU_DATA_PAPER_OFFSET+1]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(28,papersizes[2].name), NULL, paper_callback,  
+                                           TMPVAL(29,&temp[MENU_DATA_PAPER_OFFSET+2]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(30,papersizes[3].name), NULL, paper_callback,  
+                                           TMPVAL(31,&temp[MENU_DATA_PAPER_OFFSET+3]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(32,papersizes[4].name), NULL, paper_callback,  
+                                           TMPVAL(33,&temp[MENU_DATA_PAPER_OFFSET+4]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(34,papersizes[5].name), NULL, paper_callback,  
+                                           TMPVAL(35,&temp[MENU_DATA_PAPER_OFFSET+5]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(36,papersizes[6].name), NULL, paper_callback,  
+                                           TMPVAL(37,&temp[MENU_DATA_PAPER_OFFSET+6]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(38,papersizes[7].name), NULL, paper_callback,  
+                                           TMPVAL(39,&temp[MENU_DATA_PAPER_OFFSET+7]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(40,papersizes[8].name), NULL, paper_callback,  
+                                           TMPVAL(41,&temp[MENU_DATA_PAPER_OFFSET+8]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(42,papersizes[9].name), NULL, paper_callback,  
+                                           TMPVAL(43,&temp[MENU_DATA_PAPER_OFFSET+9]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(44,papersizes[10].name), NULL, paper_callback,  
+                                           TMPVAL(45,&temp[MENU_DATA_PAPER_OFFSET+10]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(46,papersizes[11].name), NULL, paper_callback,  
+                                           TMPVAL(47,&temp[MENU_DATA_PAPER_OFFSET+11]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(48,papersizes[12].name), NULL, paper_callback,  
+                                           TMPVAL(49,&temp[MENU_DATA_PAPER_OFFSET+12]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(50,papersizes[13].name), NULL, paper_callback,  
+                                           TMPVAL(51,&temp[MENU_DATA_PAPER_OFFSET+13]), NULL),
+                GNOMEUIINFO_RADIOITEM_DATA(TMPVAL(52,papersizes[14].name), NULL, paper_callback,  
+                                           TMPVAL(53,&temp[MENU_DATA_PAPER_OFFSET+14]), NULL),
                 GNOMEUIINFO_END,
         };
         
         GnomeUIInfo paperMenu[] = {
                 {GNOME_APP_UI_TOGGLEITEM, N_("_Override Document size"), N_("Override the size of page to use."), 
-                 override_paper_callback, retval, NULL,
+                 override_paper_callback, TMPVAL(54,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
                 {GNOME_APP_UI_SEPARATOR},
-                GNOMEUIINFO_RADIOLIST(paperMenu2),
+                GNOMEUIINFO_RADIOLIST(TMPVAL(55,paperMenu2)),
                 GNOMEUIINFO_END,
         };
 
         GnomeUIInfo zoomMenu[] = {
-                GNOMEUIINFO_RADIOLIST(zoomMenu2),
+                GNOMEUIINFO_RADIOLIST(TMPVAL(56,zoomMenu2)),
                 GNOMEUIINFO_END,
         };
 
         GnomeUIInfo settingsMenu[] = {
-                GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_callback, retval),
+                GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_callback, TMPVAL(57,retval)),
                 {GNOME_APP_UI_SEPARATOR},
-                {GNOME_APP_UI_TOGGLEITEM, N_("_Show Menus"), N_("Toggle menu visibility"), 
-                 show_menubar_callback, retval, NULL,
+                {GNOME_APP_UI_TOGGLEITEM, N_("Show _Menus"), N_("Toggle menu visibility"), 
+                 show_menubar_callback, TMPVAL(58,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-                {GNOME_APP_UI_TOGGLEITEM, N_("S_how Side Panel"), N_("Toggle side panel visibility"), 
-                 hide_panel_callback, retval, NULL,
+                {GNOME_APP_UI_TOGGLEITEM, N_("Show _Side Panel"), N_("Toggle side panel visibility"), 
+                 hide_panel_callback, TMPVAL(59,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
 	 	{GNOME_APP_UI_TOGGLEITEM, N_("Show _Toolbar"), N_("Toggle toolbar visibility"), 
-                 show_toolbar_callback, retval, NULL,
+                 show_toolbar_callback, TMPVAL(60,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},								  
                 GNOMEUIINFO_END
         };
 
         GnomeUIInfo fileMenu[] = {
                 {GNOME_APP_UI_ITEM, N_("_New Window"), N_("Open a new window"), 
-                 new_callback, retval, NULL,
+                 new_callback, TMPVAL(61,retval), NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 'n', GDK_CONTROL_MASK, NULL},
                 {GNOME_APP_UI_ITEM, N_("_Open..."), N_("Load a postscript document"), 
-                 open_callback, retval, NULL,
+                 open_callback, TMPVAL(62,retval), NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 'o', GDK_CONTROL_MASK, NULL},
                 {GNOME_APP_UI_ITEM, N_("_Reload"), N_("Reload current document from disk"), 
-                 reload_callback, retval, NULL,
+                 reload_callback, TMPVAL(63,retval), NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REFRESH, 'r', GDK_CONTROL_MASK, NULL},
                 {GNOME_APP_UI_SEPARATOR},
-                {GNOME_APP_UI_ITEM, N_("_Print"), N_("Print the document"), print_callback, retval, NULL,
+                {GNOME_APP_UI_ITEM, N_("_Print"), N_("Print the document"), print_callback, TMPVAL(64,retval), NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PRINT, 'p', GDK_CONTROL_MASK, NULL },
-                {GNOME_APP_UI_ITEM, N_("Prin_t marked pages"), N_("Print marked pages"), print_marked_pages_callback, retval, NULL,
+                {GNOME_APP_UI_ITEM, N_("Prin_t marked pages"), N_("Print marked pages"), print_marked_pages_callback, TMPVAL(65,retval), NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PRINT, 0, 0, NULL },
-                {GNOME_APP_UI_ITEM, N_("Save _marked pages..."), N_("Save marked pages to a new file"), save_callback, retval, NULL,
+                {GNOME_APP_UI_ITEM, N_("Save _marked pages..."), N_("Save marked pages to a new file"), save_callback, TMPVAL(66,retval), NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 0, 0, NULL},
                 /* Not implemented yet 
                 {GNOME_APP_UI_ITEM, N_("Save _As..."), N_("Save document to a new file"), save_as_callback, retval, NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 0, 0, NULL},
                 */
                 {GNOME_APP_UI_SEPARATOR},
-                {GNOME_APP_UI_ITEM, N_("_Close"), N_("Close this window"), close_callback, retval, NULL,
+                {GNOME_APP_UI_ITEM, N_("_Close"), N_("Close this window"), close_callback, TMPVAL(67,retval), NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE, 'w', GDK_CONTROL_MASK, NULL },
                 {GNOME_APP_UI_SEPARATOR},
-                {GNOME_APP_UI_ITEM, N_("E_xit"), N_("Exit GGv"), exit_callback, retval, NULL,
+                {GNOME_APP_UI_ITEM, N_("E_xit"), N_("Exit GGv"), exit_callback, TMPVAL(68,retval), NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'q', GDK_CONTROL_MASK, NULL },
                 {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
         };
 
         GnomeUIInfo documentMenu[] = {
-                {GNOME_APP_UI_ITEM, N_("_Next Page"), N_("Show next page"), next_page_callback, retval, NULL,
+                {GNOME_APP_UI_ITEM, N_("_Next Page"), N_("Show next page"), next_page_callback, TMPVAL(69,retval), NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_FORWARD, 0, 0, NULL},
-                {GNOME_APP_UI_ITEM, N_("_Previous Page"), N_("Show previous page"), previous_page_callback, retval, NULL,
+                {GNOME_APP_UI_ITEM, N_("_Previous Page"), N_("Show previous page"), previous_page_callback, TMPVAL(70,retval), NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BACK, 0, 0, NULL},
-                {GNOME_APP_UI_ITEM, N_("_Recenter Page"), N_("Center page"), recenter_page_callback, retval, NULL,
+                {GNOME_APP_UI_ITEM, N_("_Recenter Page"), N_("Center page"), recenter_page_callback, TMPVAL(71,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
                 {GNOME_APP_UI_SEPARATOR},
-                {GNOME_APP_UI_ITEM, N_("Toggle _current page"), NULL, toggle_current_page_callback, retval,NULL,
+                {GNOME_APP_UI_ITEM, N_("Toggle _current page"), NULL, toggle_current_page_callback, TMPVAL(72,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-                {GNOME_APP_UI_ITEM, N_("Toggle _all pages"), NULL, toggle_all_pages_callback, retval,NULL,
+                {GNOME_APP_UI_ITEM, N_("Toggle _all pages"), NULL, toggle_all_pages_callback, TMPVAL(73,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-                {GNOME_APP_UI_ITEM, N_("Toggle _odd pages"), NULL, toggle_odd_pages_callback, retval,NULL,
+                {GNOME_APP_UI_ITEM, N_("Toggle _odd pages"), NULL, toggle_odd_pages_callback, TMPVAL(74,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-                {GNOME_APP_UI_ITEM, N_("Toggle _even pages"), NULL, toggle_even_pages_callback, retval,NULL,
+                {GNOME_APP_UI_ITEM, N_("Toggle _even pages"), NULL, toggle_even_pages_callback, TMPVAL(75,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-                {GNOME_APP_UI_ITEM, N_("_Unmark all pages"), NULL, unmark_all_pages_callback, retval,NULL,
+                {GNOME_APP_UI_ITEM, N_("_Unmark all pages"), NULL, unmark_all_pages_callback, TMPVAL(76,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
                 {GNOME_APP_UI_SEPARATOR},
-                {GNOME_APP_UI_TOGGLEITEM, N_("_Antialiasing"), N_("Toggle antialiasing"), antialiasing_callback, retval, NULL,
+                {GNOME_APP_UI_TOGGLEITEM, N_("Antia_liasing"), N_("Toggle antialiasing"), antialiasing_callback, TMPVAL(77,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-                {GNOME_APP_UI_TOGGLEITEM, N_("_Watch File"), N_("Updates display if file changes."), watch_file_callback, retval, NULL,
+                {GNOME_APP_UI_TOGGLEITEM, N_("_Watch File"), N_("Updates display if file changes."), watch_file_callback, TMPVAL(78,retval), NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-                {GNOME_APP_UI_SUBTREE, N_("_Orientation"), NULL, orientationMenu, NULL, NULL,
+                {GNOME_APP_UI_SUBTREE, N_("Orien_tation"), NULL, TMPVAL(79,orientationMenu), NULL, NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-                {GNOME_APP_UI_SUBTREE, N_("_Zoom"), NULL, zoomMenu, NULL, NULL,
+                {GNOME_APP_UI_SUBTREE, N_("_Zoom"), NULL, TMPVAL(80,zoomMenu), NULL, NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-                {GNOME_APP_UI_SUBTREE, N_("_Page Size"), NULL, paperMenu, NULL, NULL,
+                {GNOME_APP_UI_SUBTREE, N_("Page _Size"), NULL, TMPVAL(81,paperMenu), NULL, NULL,
                  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
                 {GNOME_APP_UI_ENDOFINFO}
         };
         
         GnomeUIInfo helpMenu[] = {
                 GNOMEUIINFO_HELP("ggv"),
-                GNOMEUIINFO_MENU_ABOUT_ITEM(about_callback, retval),
+                GNOMEUIINFO_MENU_ABOUT_ITEM(about_callback, TMPVAL(82,retval)),
                 GNOMEUIINFO_END
         };
         
         GnomeUIInfo mainMenu[] = {
-                GNOMEUIINFO_MENU_FILE_TREE(fileMenu),
-                GNOMEUIINFO_SUBTREE(N_("_Document"), documentMenu),
-                GNOMEUIINFO_MENU_SETTINGS_TREE(settingsMenu),
-                GNOMEUIINFO_MENU_HELP_TREE(helpMenu),
+                GNOMEUIINFO_MENU_FILE_TREE(TMPVAL(83,fileMenu)),
+                GNOMEUIINFO_SUBTREE(N_("_Document"), TMPVAL(84,documentMenu)),
+                GNOMEUIINFO_MENU_SETTINGS_TREE(TMPVAL(85,settingsMenu)),
+                GNOMEUIINFO_MENU_HELP_TREE(TMPVAL(86,helpMenu)),
                 GNOMEUIINFO_END
         };
 
+	/* Initialize pseudo-constan fields. */
+        SETVAL(0,orientationMenu2[0].user_data,&temp[0]);
+        SETVAL(1,orientationMenu2[1].user_data,&temp[1]);
+        SETVAL(2,orientationMenu2[2].user_data,&temp[2]);
+        SETVAL(3,orientationMenu2[3].user_data,&temp[3]);
+        SETVAL(4,orientationMenu[0].user_data,retval);
+        SETVAL(5,orientationMenu[2].moreinfo,orientationMenu2);
+        SETVAL(6,zoomMenu2[0].label,ZoomMagnLabels[0]);
+        SETVAL(7,zoomMenu2[0].user_data,&temp[4]);
+        SETVAL(8,zoomMenu2[1].label,ZoomMagnLabels[1]);
+        SETVAL(9,zoomMenu2[1].user_data,&temp[5]);
+        SETVAL(10,zoomMenu2[2].label,ZoomMagnLabels[2]);
+        SETVAL(11,zoomMenu2[2].user_data,&temp[6]);
+        SETVAL(12,zoomMenu2[3].label,ZoomMagnLabels[3]);
+        SETVAL(13,zoomMenu2[3].user_data,&temp[7]);
+        SETVAL(14,zoomMenu2[4].label,ZoomMagnLabels[4]);
+        SETVAL(15,zoomMenu2[4].user_data,&temp[8]);
+        SETVAL(16,zoomMenu2[5].label,ZoomMagnLabels[5]);
+        SETVAL(17,zoomMenu2[5].user_data,&temp[9]);
+        SETVAL(18,zoomMenu2[6].label,ZoomMagnLabels[6]);
+        SETVAL(19,zoomMenu2[6].user_data,&temp[10]);
+        SETVAL(20,zoomMenu2[7].label,ZoomMagnLabels[7]);
+        SETVAL(21,zoomMenu2[7].user_data,&temp[11]);
+        SETVAL(22,zoomMenu2[8].label,ZoomMagnLabels[8]);
+        SETVAL(23,zoomMenu2[8].user_data,&temp[14]);
+        SETVAL(24,paperMenu2[0].label,papersizes[0].name);
+        SETVAL(25,paperMenu2[0].user_data,&temp[MENU_DATA_PAPER_OFFSET]);
+        SETVAL(26,paperMenu2[1].label,papersizes[1].name);
+        SETVAL(27,paperMenu2[1].user_data,&temp[MENU_DATA_PAPER_OFFSET+1]);
+        SETVAL(28,paperMenu2[2].label,papersizes[2].name);
+        SETVAL(29,paperMenu2[2].user_data,&temp[MENU_DATA_PAPER_OFFSET+2]);
+        SETVAL(30,paperMenu2[3].label,papersizes[3].name);
+        SETVAL(31,paperMenu2[3].user_data,&temp[MENU_DATA_PAPER_OFFSET+3]);
+        SETVAL(32,paperMenu2[4].label,papersizes[4].name);
+        SETVAL(33,paperMenu2[4].user_data,&temp[MENU_DATA_PAPER_OFFSET+4]);
+        SETVAL(34,paperMenu2[5].label,papersizes[5].name);
+        SETVAL(35,paperMenu2[5].user_data,&temp[MENU_DATA_PAPER_OFFSET+5]);
+        SETVAL(36,paperMenu2[6].label,papersizes[6].name);
+        SETVAL(37,paperMenu2[6].user_data,&temp[MENU_DATA_PAPER_OFFSET+6]);
+        SETVAL(38,paperMenu2[7].label,papersizes[7].name);
+        SETVAL(39,paperMenu2[7].user_data,&temp[MENU_DATA_PAPER_OFFSET+7]);
+        SETVAL(40,paperMenu2[8].label,papersizes[8].name);
+        SETVAL(41,paperMenu2[8].user_data,&temp[MENU_DATA_PAPER_OFFSET+8]);
+        SETVAL(42,paperMenu2[9].label,papersizes[9].name);
+        SETVAL(43,paperMenu2[9].user_data,&temp[MENU_DATA_PAPER_OFFSET+9]);
+        SETVAL(44,paperMenu2[10].label,papersizes[10].name);
+        SETVAL(45,paperMenu2[10].user_data,&temp[MENU_DATA_PAPER_OFFSET+10]);
+        SETVAL(46,paperMenu2[11].label,papersizes[11].name);
+        SETVAL(47,paperMenu2[11].user_data,&temp[MENU_DATA_PAPER_OFFSET+11]);
+        SETVAL(48,paperMenu2[12].label,papersizes[12].name);
+        SETVAL(49,paperMenu2[12].user_data,&temp[MENU_DATA_PAPER_OFFSET+12]);
+        SETVAL(50,paperMenu2[13].label,papersizes[13].name);
+        SETVAL(51,paperMenu2[13].user_data,&temp[MENU_DATA_PAPER_OFFSET+13]);
+        SETVAL(52,paperMenu2[14].label,papersizes[14].name);
+        SETVAL(53,paperMenu2[14].user_data,&temp[MENU_DATA_PAPER_OFFSET+14]);
+        SETVAL(54,paperMenu[0].user_data,retval);
+        SETVAL(55,paperMenu[2].moreinfo,paperMenu2);
+        SETVAL(56,zoomMenu[0].moreinfo,zoomMenu2);
+        SETVAL(57,settingsMenu[0].user_data,retval);
+        SETVAL(58,settingsMenu[2].user_data,retval);
+        SETVAL(59,settingsMenu[3].user_data,retval);
+        SETVAL(60,settingsMenu[4].user_data,retval);
+        SETVAL(61,fileMenu[0].user_data,retval);
+        SETVAL(62,fileMenu[1].user_data,retval);
+        SETVAL(63,fileMenu[2].user_data,retval);
+        SETVAL(64,fileMenu[4].user_data,retval);
+        SETVAL(65,fileMenu[5].user_data,retval);
+        SETVAL(66,fileMenu[6].user_data,retval);
+        SETVAL(67,fileMenu[8].user_data,retval);
+        SETVAL(68,fileMenu[10].user_data,retval);
+        SETVAL(69,documentMenu[0].user_data,retval);
+        SETVAL(70,documentMenu[1].user_data,retval);
+        SETVAL(71,documentMenu[2].user_data,retval);
+        SETVAL(72,documentMenu[4].user_data,retval);
+        SETVAL(73,documentMenu[5].user_data,retval);
+        SETVAL(74,documentMenu[6].user_data,retval);
+        SETVAL(75,documentMenu[7].user_data,retval);
+        SETVAL(76,documentMenu[8].user_data,retval);
+        SETVAL(77,documentMenu[10].user_data,retval);
+        SETVAL(78,documentMenu[11].user_data,retval);
+        SETVAL(79,documentMenu[12].moreinfo,orientationMenu);
+        SETVAL(80,documentMenu[13].moreinfo,zoomMenu);
+        SETVAL(81,documentMenu[14].moreinfo,paperMenu);
+        SETVAL(82,helpMenu[1].user_data,retval);
+        SETVAL(83,mainMenu[0].moreinfo,fileMenu);
+        SETVAL(84,mainMenu[1].moreinfo,documentMenu);
+        SETVAL(85,mainMenu[2].moreinfo,settingsMenu);
+        SETVAL(86,mainMenu[3].moreinfo,helpMenu);
+#undef TMPVAL
+#undef SETVAL
 
         /* We set up the main window... */
         gnome_app_create_menus(GNOME_APP(retval->main_window), mainMenu);
@@ -960,8 +1058,6 @@ void create_menus(ggv_window *retval, window_with_data *temp)
 
 void create_toolbar(ggv_window *retval)
 {
-	GnomeDockItem* dock_item;
-
 	GnomeUIInfo toolbar [] = {
 		GNOMEUIINFO_ITEM_STOCK (N_("New"), N_("Create a new window"), new_callback, GNOME_STOCK_PIXMAP_NEW),
 		GNOMEUIINFO_ITEM_STOCK (N_("Open"), N_("Load a postscript document"), open_callback, GNOME_STOCK_PIXMAP_OPEN),
@@ -988,11 +1084,6 @@ void create_toolbar(ggv_window *retval)
 	gtk_widget_set_sensitive(GTK_WIDGET(retval->reloadbutton), FALSE);
 	gtk_widget_set_sensitive(GTK_WIDGET(retval->printbutton), FALSE);
 	gtk_widget_set_sensitive(GTK_WIDGET(retval->savebutton), FALSE);
-
-	dock_item = gnome_app_get_dock_item_by_name(GNOME_APP(retval->main_window), GNOME_APP_TOOLBAR_NAME);
-	
-	gtk_toolbar_set_style(GTK_TOOLBAR(gnome_dock_item_get_child(dock_item)), 
-                              GTK_TOOLBAR_ICONS);
 }
 
 void create_sidebar(ggv_window *retval)
