@@ -19,8 +19,8 @@ gchar *gs_unbzip2_cmd = NULL;
 gchar *gs_print_cmd = NULL;
 
 gboolean gs_save_geometry;
-gint ggv_default_width;
-gint ggv_default_height;
+gint ggv_default_width, file_sel_width;
+gint ggv_default_height, file_sel_height;
 
 gboolean gs_panel, gs_menubar, gs_toolbar;
 gboolean gs_auto_jump;
@@ -132,12 +132,14 @@ load_prefs(gchar *prefix)
 
         /* Get geometry */
         gs_save_geometry = gnome_config_get_bool("Layout/SaveGeometry=false");
-
         if((ggv_default_width = gnome_config_get_int("Layout/SaveGeometryX")) == 0)
                 ggv_default_width = DEFAULT_WINDOW_WIDTH;
-
         if((ggv_default_height = gnome_config_get_int("Layout/SaveGeometryY")) == 0)
                 ggv_default_height = DEFAULT_WINDOW_HEIGHT;
+        if((file_sel_width = gnome_config_get_int("Layout/FileSelWidth")) == 0)
+                file_sel_width = DEFAULT_FILE_SEL_WIDTH;
+        if((file_sel_height = gnome_config_get_int("Layout/FileSelHeight")) == 0)
+                file_sel_height = DEFAULT_FILE_SEL_WIDTH;
 
         gnome_config_pop_prefix();
 }
@@ -150,31 +152,30 @@ save_prefs(gchar *prefix)
         gnome_config_set_string("GhostScript/ScanPDF", gs_scan_pdf_cmd);
         gnome_config_set_string("GhostScript/Ungzip", gs_ungzip_cmd);
         gnome_config_set_string("GhostScript/Unbzip2", gs_unbzip2_cmd);
+
         gnome_config_set_string("Printing/Command", gs_print_cmd);
+
         gnome_config_set_int("Document/Magnification", gs_default_magnification);
         gnome_config_set_string("Document/Media", papersizes[gtk_gs_get_default_page_media()].name);
         gnome_config_set_bool("Document/OverrideDocumentMedia", gtk_gs_get_default_override_media());
         gnome_config_set_bool("Document/Antialiasing", gtk_gs_get_default_antialiased());
-
         gnome_config_set_bool("Document/OverrideOrientation", 
                               gtk_gs_get_default_override_orientation());
-
         gnome_config_set_string("Document/Orientation", 
                                 OrientationLabels[gtk_gs_get_default_orientation()]);
-
-
         gnome_config_set_bool("Document/Watch", gtk_gs_get_default_watch_doc());
+        gnome_config_set_bool("Document/RespectEOF", gtk_gs_get_default_respect_eof());
+
         gnome_config_set_bool("Layout/ShowPanel", gs_panel);
 	gnome_config_set_bool("Layout/ShowToolbar", gs_toolbar);
         gnome_config_set_bool("Layout/ShowMenubar", gs_menubar);
         gnome_config_set_bool("Layout/AutoJump", gs_auto_jump);
-
-
         gnome_config_set_bool("Layout/SaveGeometry", gs_save_geometry);
-
         if(gs_save_geometry) {
                 gnome_config_set_int("Layout/SaveGeometryX", ggv_default_width);
                 gnome_config_set_int("Layout/SaveGeometryY", ggv_default_height);
+                gnome_config_set_int("Layout/FileSelWidth", file_sel_width);
+                gnome_config_set_int("Layout/FileSelHeight", file_sel_height);
         }
 
         gnome_config_pop_prefix();
